==> gtg_0.2.4.orig.tar.gz: gtg-0.2.4/GTG/info.py <==
# -*- coding: utf-8 -*-
#various information about GTG. Should be updated for every release.

URL             = "http://gtg.fritalk.com"
EMAIL           = "gtg-contributors@lists.launchpad.net"
VERSION         = '0.2.4'

SHORT_DESCRIPTION = 'GTG is a personal organizer for the GNOME desktop environment.'

# CREDITS
AUTHORS     = ["Main developers:", \
               "\tLionel Dricot <ploum@ploum.net>", \
               "\tBertrand Rousseau <bertrand.rousseau@gmail.com>", \
               "\tPaulo Cabido <paulo.cabido@gmail.com>", \
               "\tLuca Invernizzi <invernizzi.l@gmail.com>", \
               "\tKevin Mehall <km@kevinmehall.net>", \
               "\tLuca Falavigna <dktrkranz@debian.org>", \
               "Contributors:", \
               "\tGérôme Fournier <>", \
               "\tAntons Rebguns <arebgun@gmail.com>", \
               "\tCarl Chenet <chaica@ohmytux.com>", \
               "\tJérôme Guelfucci <jerome.guelfucci@gmail.com>",      \
               "\tKalle Persson <kalle@kallepersson.se>", \
               "\tJonathan Barnoud <jonathan@barnoud.net>", \
               "\tMichael Vogt <michael.vogt@ubuntu.com>", \
               "\tBen Dowling <ben.m.dowling@gmail.com>", \
               "\tBrian Kennedy <ekspiulo@gmail.com>", \
               "\tZach Shepherd <eightball1989@gmail.com>", \
               "\tJean-François Fortin Tam <nekohayo@gmail.com>", \
               "\tJonathan Lange <jml@mumak.net>", \
               "\tMatthew Rasmus <tareth.ml@gmail.com>", \
               "\tBryce Harrington <bryce@bryceharrington.org>", \
               "\tChris Johnston <chrisjohnston@ubuntu.com>", \
               "\tDavid Planella <david.planella@jabber.org>", \
]
ARTISTS     = ["Kalle Persson <kalle@kallepersson.se>", \
                "Bertrand Rousseau <bertrand.rousseau@gmail.com>"]
ARTISTS.sort()
TRANSLATORS = \
"""Afrikaans: Walter Leibbrandt
Belarusian: Egor Kuryanovich, Iryna Nikanchuk
Catalan: Siegfried Gevatter
Czech: Hýroumen, Ladislav Prskavec
Danish: Peter Skov
Dutch: puccha
Finnish: Mika Tapojärvi
French: Lionel Dricot, Rafik Ouerchefani, Bertrand Rousseau, Pititjo
German: Philip Stewart, Thomas Pitlik
Italian: Luca Falavigna, Luca Invernizzi
Malay: melayubuntu
Polish: Tomasz Maciejewski
Portuguese: Paulo Cabido 
Russian: Alexey Kostyuk, Alexey Nedilko, a220, mrk, wiz
Simplified Chinese: Harold.luo
Spanish: David Prieto, DiegoJ, Pititjo
Swedish: Christian Widell, Daniel Holm, Kalle Persson, Petri Rosenström
Turkish: Murat Güneş"""

==> gtg_0.2.9.orig.tar.gz: gtg-0.2.9/GTG/info.py <==
# -*- coding: utf-8 -*-
"""Various information about GTG. Should be updated for every release. Contains the information displayed in GTG's Credits."""

NAME            = "Getting Things GNOME!"
URL             = "http://gtg.fritalk.com"
EMAIL           = "gtg-contributors@lists.launchpad.net"
VERSION         = '0.2.9'

SHORT_DESCRIPTION = 'GTG is a personal organizer for the GNOME desktop environment.'

# CREDITS
AUTHORS     = ["Main developers:", \
               "\tLionel Dricot <ploum@ploum.net>", \
               "\tBertrand Rousseau <bertrand.rousseau@gmail.com>", \
               "\tPaulo Cabido <paulo.cabido@gmail.com>", \
               "\tLuca Invernizzi <invernizzi.l@gmail.com>", \
               "\tKevin Mehall <km@kevinmehall.net>", \
               "\tLuca Falavigna <dktrkranz@debian.org>", \
               "\tIzidor Matušov <izidor.matusov@gmail.com>", \
               "Contributors:", \
               "\tAlayn Gortazar <zutoin@gmail.com>", \
               "\tAndrew Starr-Bochicchio <andrewsomething@ubuntu.com>", \
               "\tAntons Rebguns <arebgun@gmail.com>", \
               "\tBen Dowling <ben.m.dowling@gmail.com>", \
               "\tBrian Kennedy <ekspiulo@gmail.com>", \
               "\tBryce Harrington <bryce@bryceharrington.org>", \
               "\tCarl Chenet <chaica@ohmytux.com>", \
               "\tChris Johnston <chrisjohnston@ubuntu.com>", \
               "\tDaniel Neel <dneelyep@gmail.com>", \
               "\tDavid Planella <david.planella@jabber.org>", \
               "\tErin McLaughlin <emclaughlin1215@gmail.com>", \
               "\tFabio Prina <fabio@nimsh.com>", \
               "\tFrançois <>", \
               "\tGérôme Fournier <>", \
               "\tIvan Evtukhovich <evtuhovich@gmail.com>", \
               "\tJean-François Fortin Tam <nekohayo@gmail.com>", \
               "\tJeff Oliver <kaiserfro@gmail.com>", \
               "\tJérôme Guelfucci <jerome.guelfucci@gmail.com>",      \
               "\tJoão Ascenso <joaoricardoascenso@gmail.com>", \
               "\tJonathan Barnoud <jonathan@barnoud.net>", \
               "\tJonathan Lange <jml@mumak.net>", \
               "\tKalle Persson <kalle@kallepersson.se>", \
               "\tKees Cook <kees@ubuntu.com>", \
               "\tMadhumitha Viswanathan <madhuvishy@gmail.com>", \
               "\tMarcos Lenharo <>", \
               "\tMarko Kevac <marko@kevac.org>", \
               "\tMatthew Rasmus <tareth.ml@gmail.com>", \
               "\tMichael Vogt <michael.vogt@ubuntu.com>", \
               "\tNicolas Maître <nimai@skynet.be>", \
               "\tRichard Klein <kleinric@gmail.com>", \
               "\tThibault Fevry <ThibaultFevry@gmail.com>", \
               "\tViktor Nagy <viktor.nagy@toolpart.hu>", \
               "\tVolodymyr Floreskul <exufer@gmail.com>", \
               "\tZach Shepherd <eightball1989@gmail.com>", \
               "\tZimin Huang <ienjoycoding@gmail.com>", \
]
ARTISTS     = ["Kalle Persson <kalle@kallepersson.se>", \
                "Bertrand Rousseau <bertrand.rousseau@gmail.com>"]
ARTISTS.sort()
TRANSLATORS = \
"""Afrikaans: Walter Leibbrandt
Belarusian: Egor Kuryanovich, Iryna Nikanchuk
Catalan: Siegfried Gevatter
Czech: Hýroumen, Ladislav Prskavec
Danish: Peter Skov
Dutch: puccha
Finnish: Mika Tapojärvi
French: Lionel Dricot, Rafik Ouerchefani, Bertrand Rousseau, Pititjo
German: Philip Stewart, Thomas Pitlik
Italian: Luca Falavigna, Luca Invernizzi
Malay: melayubuntu
Polish: Tomasz Maciejewski
Portuguese: Paulo Cabido 
Russian: Alexey Kostyuk, Alexey Nedilko, a220, mrk, wiz
Simplified Chinese: Harold.luo
Slovak: Slavko (linux-slavino)
Spanish: David Prieto, DiegoJ, Pititjo
Swedish: Christian Widell, Daniel Holm, Kalle Persson, Petri Rosenström
Traditional Chinese: Rex Tsai
Turkish: Murat Güneş"""
